@@ -223,7 +223,7 @@ class ReduceAddBTransform(FTransform):
         super(ReduceAddBTransform,self).__init__('hadd',reduce_add_meth_b,prefer=prefer)
     
     def output(self,type,width,intr):
-        ms = int_log2(width/type.size) - 2
+        ms = int_log2(width//type.size) - 2
         if ms:
             ms = '\n            r = {0}(r,r);'.format(intr['name']) * ms
         else:
@@ -503,7 +503,7 @@ mask_search = re.compile(r'^\s*//\s*\[\[\[mask-(\d+)-(\d+)\]\]\]\s*$')
 
 
 def generate(data_file,template_file,output_file):
-    with open(data_file,'rb') as input:
+    with open(data_file,'r') as input:
         data = json.load(input)
 
     intrinsics = {}
@@ -513,8 +513,8 @@ def generate(data_file,template_file,output_file):
     del data
 
 
-    template = open(template_file,'rb')
-    output = open(output_file,'wb')
+    template = open(template_file,'r')
+    output = open(output_file,'w')
 
     print('// THIS FILE WAS GENERATED BY generate_simd.py. DO NOT EDIT IT DIRECTLY.\n\n',file=output)
 
